asciidocBy default, knitr renders messages, warnings and errors to
[NOTE|WARNING|ERROR]-blocks in asciidoc, which is ... not my
choice.
To restore knitr's behaviour, set hooks or replacement to
NULL.
adjust_asciidoc_hooks(
hooks = c("message", "error", "warning"),
replacement = "source"
)The return value of
knit_hooks$set,
invisibly
NULL, currently.
Character vector naming the output hooks to be replaced by
the replacement's hooks.
The hook with which to replace the hooks given by
hooks.
This is a modified version of
render_asciidoc of knitr
version 1.18.7.